Skip to contents

Calculates trend strength, linearity, and curvature using the feasts and fabletools packages functionality.

Usage

compute_trend_shape_features(wdi_data, index = NULL, verbose = TRUE)

Arguments

wdi_data

A data frame of the indicator data generated by get_wdi_data

index

An optional character string specifying the indicator code Defaults to NULL

verbose

Logical, if TRUE, the message about the data download is printed. If FALSE, it is silenced.

Value

A data frame with columns country, trend_strength, linearity, curvature, and smoothness.

Examples

pm_trend_shape <- compute_trend_shape_features(pm_data, verbose = TRUE)