Create and store the data for the specified indicator code in a folder called wdi_data.
Usage
get_wdi_data(indicator, verbose = TRUE)
Arguments
- indicator
A valid WDI indicator code
- verbose
Logical, if TRUE, the message about the data download is printed. If FALSE, it is silenced. Default to TRUE
Value
An .rds file containing the data set for the specified indicator code.
Examples
pm_data <- get_wdi_data(indicator = "EN.ATM.PM25.MC.M3", verbose = TRUE)
#> Downloading WDI indicator: EN.ATM.PM25.MC.M3